@@ -470,7 +470,7 @@ class TicketOrderChecker(Checker):
                         **dd.str2kw("name", _("Service Level Agreements")))
                     jnl.full_clean()
                     jnl.save()
-                sub = Subscription(partner=obj.site.company, jnl=jnl, ref=obj.site.ref)
+                sub = Subscription(partner=obj.site.company, journal=jnl, ref=obj.site.ref)
                 sub.full_clean()
                 sub.save()
             obj.order = sub
